pub struct RedisCommand { /* private fields */ }Expand description
A RedisCommand purpose is to build redis commands. It can contains one or more commands for pipelining
Example:
let cmd = &mut redis_client::RedisCommand::new();
cmd.set("key", "value2").get("key");or its equivalent:
let cmd = &mut redis_client::RedisCommand::new();
cmd.add_cmd("SET").add_arg("key").add_arg("value2").end().add_cmd("GET").add_arg("key").end();Implementations
Sourceimpl RedisCommand
impl RedisCommand
pub fn new() -> RedisCommand
Sourcepub fn add_cmd<C>(&mut self, command: C) -> &mut RedisCommandwhere
C: ToString,
pub fn add_cmd<C>(&mut self, command: C) -> &mut RedisCommandwhere
C: ToString,
Add a string representing the command (APPEND, GET, SET…) to the command. (Each command should start with this method)
Sourcepub fn add_arg<A>(&mut self, arg: A) -> &mut RedisCommandwhere
A: ToString,
pub fn add_arg<A>(&mut self, arg: A) -> &mut RedisCommandwhere
A: ToString,
Add a whitespace and a string to the commands
Sourcepub fn add_args<A>(&mut self, args: Vec<A>) -> &mut RedisCommandwhere
A: ToString,
pub fn add_args<A>(&mut self, args: Vec<A>) -> &mut RedisCommandwhere
A: ToString,
Add a whitespace and a string for each one of the vector’s items to the commands
Sourcepub fn add_arg_map<F: ToString>(
&mut self,
args: HashMap<String, F>,
) -> &mut RedisCommand
pub fn add_arg_map<F: ToString>( &mut self, args: HashMap<String, F>, ) -> &mut RedisCommand
Add a whitespace a key another whitespace and the value for each pair of the hash map to the curent command
Sourcepub fn add_binary_arg(&mut self, arg: &[u8]) -> &mut RedisCommand
pub fn add_binary_arg(&mut self, arg: &[u8]) -> &mut RedisCommand
Add a whitespace and then an array of byte to the command
Sourcepub fn end(&mut self) -> &mut RedisCommand
pub fn end(&mut self) -> &mut RedisCommand
Teminate a command
Sourcepub fn get_command_nb(&self) -> usize
pub fn get_command_nb(&self) -> usize
Get the number of commands in the RedisCommand object